# mypy-boto3-storagegateway

[![PyPI - mypy-boto3-storagegateway](https://img.shields.io/pypi/v/mypy-boto3-storagegateway.svg?color=blue)](https://pypi.org/project/mypy-boto3-storagegateway)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-storagegateway.svg?color=blue)](https://pypi.org/project/mypy-boto3-storagegateway)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)

Type annotations for
[boto3.StorageGateway 1.14.5](https://boto3.amazonaws.com/v1/documentation/api/1.14.5/reference/services/storagegateway.html#StorageGateway) service
compatible with [mypy](https://github.com/python/mypy), [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/) and other tools.

Generated by [mypy-boto3-buider 2.2.0](https://github.com/vemel/mypy_boto3_builder).

More information can be found on [boto3-stubs](https://pypi.org/project/boto3-stubs/) page.

## How to install

Make sure you have [mypy](https://github.com/python/mypy) installed and activated in your IDE.

Install `boto3-stubs` for `StorageGateway` service.

```bash
python -m pip install boto3-stubs[storagegateway]
```

## How to use

### Client annotations

`StorageGatewayClient` provides annotations for `boto3.client("storagegateway")`.

```python
import boto3

from mypy_boto3_storagegateway import StorageGatewayClient
from mypy_boto3_storagegateway.paginator import (
    DescribeTapeArchivesPaginator,
    DescribeTapeRecoveryPointsPaginator,
    DescribeTapesPaginator,
    DescribeVTLDevicesPaginator,
    ListFileSharesPaginator,
    ListGatewaysPaginator,
    ListTagsForResourcePaginator,
    ListTapesPaginator,
    ListVolumesPaginator,
)
from mypy_boto3_storagegateway.type_defs import AutomaticTapeCreationPolicyInfoTypeDef, ...

client: StorageGatewayClient = boto3.client("storagegateway")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: StorageGatewayClient = session.client("storagegateway")
```

### Paginators annotations

`mypy_boto3_storagegateway.paginator` module contains type annotations for all paginators.

```python

client: StorageGatewayClient = boto3.client("storagegateway")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
describe_tape_archives_paginator: DescribeTapeArchivesPaginator = client.get_paginator("describe_tape_archives")
describe_tape_recovery_points_paginator: DescribeTapeRecoveryPointsPaginator = client.get_paginator("describe_tape_recovery_points")
describe_tapes_paginator: DescribeTapesPaginator = client.get_paginator("describe_tapes")
describe_vtl_devices_paginator: DescribeVTLDevicesPaginator = client.get_paginator("describe_vtl_devices")
list_file_shares_paginator: ListFileSharesPaginator = client.get_paginator("list_file_shares")
list_gateways_paginator: ListGatewaysPaginator = client.get_paginator("list_gateways")
list_tags_for_resource_paginator: ListTagsForResourcePaginator = client.get_paginator("list_tags_for_resource")
list_tapes_paginator: ListTapesPaginator = client.get_paginator("list_tapes")
list_volumes_paginator: ListVolumesPaginator = client.get_paginator("list_volumes")
```







### Typed dictionations

`mypy_boto3_storagegateway.type_defs` module contains structures and shapes assembled
to typed dictionaries for additional type checking.

```python

def get_structure() -> AutomaticTapeCreationPolicyInfoTypeDef:
    return {
      ...
    }
```


## Dynamic type annotations

`mypy_boto3` command generates `boto3.client/resource` type annotations for
`mypy_boto3_storagegateway` and other installed services.

```bash
# Run this command after you add or remove service packages
python -m mypy_boto3
```

Generated type annotations provide overloads for `boto3.client` and `boto3.resource`,
`boto3.Session.client` and `boto3.Session.resource` functions,
so explicit type annotations are not needed.

- `mypy` supports function overloads as expected
- `PyCharm` also supports function overloads, but consumes a lot of RAM, use carefully if you have many services installed
- `VSCode` does not currently support function overloads, use explicit type annotations

```python

# Type is discovered correctly by mypy and PyCharm
# VSCode still needs explicit type annotations
client = boto3.client("storagegateway")

session_client = boto3.Session().client("storagegateway")
```
